import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="calories",
    version="0.1.0",
    author="takisawa kazuma",
    author_email="ktakisawa@sciencepark.co.jp",
    description="A simple package to calculate calories",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/ktakisawa/calories",
    project_urls={
        "Bug Tracker": "https://github.com/ktakisawa/calories/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    package_dir={"": "src"},
    py_modules=['calories'],
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.8",
     entry_points={
        'console_scripts': [
            'calories = calories:main'
        ]
    },
)